'''
billing customer
'''
from ... pyaz_utils import _call_az

def list(account_name, filter=None, profile_name=None, search=None):
    '''
    List the customers that are billed to a billing account. The operation is supported only for billing accounts with agreement type Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - filter -- May be used to filter the list of customers.
    - profile_name -- The ID that uniquely identifies a billing profile.
    - search -- Used for searching customers by their name. Any customer with name containing the search text will be included in the response
    '''
    return _call_az("az billing customer list", locals())


def show(account_name, name, expand=None):
    '''
    Get a customer by its ID. The operation is supported only for billing accounts with agreement type Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a customer.

    Optional Parameters:
    - expand -- May be used to expand enabledAzurePlans and resellers
    '''
    return _call_az("az billing customer show", locals())




'''
Manage Network Watcher troubleshooting sessions.
'''
from .... pyaz_utils import _call_az

def start(resource, storage_account, storage_path, no_wait=None, resource_group=None, resource_type=None):
    '''
    Troubleshoot issues with VPN connections or gateway connectivity.

    Required Parameters:
    - resource -- Name or ID of the resource to troubleshoot.
    - storage_account -- None
    - storage_path -- None

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type
    '''
    return _call_az("az network watcher troubleshooting start", locals())


def show(resource, resource_group=None, resource_type=None):
    '''
    Get the results of the last troubleshooting operation.

    Required Parameters:
    - resource -- Name or ID of the resource to troubleshoot.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type
    '''
    return _call_az("az network watcher troubleshooting show", locals())




'''
Manage Azure Cosmos DB SQL triggers.
'''
from .... pyaz_utils import _call_az

def create(account_name, body, container_name, database_name, name, resource_group, operation=None, type=None):
    '''
    Create an SQL trigger under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - body -- Trigger body, you can enter it as a string or as a file, e.g., --body @triggerbody-file.json
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- Trigger name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - operation -- The operation of the trigger.
    - type -- Trigger type
    '''
    return _call_az("az cosmosdb sql trigger create", locals())


def update(account_name, container_name, database_name, name, resource_group, body=None, operation=None, type=None):
    '''
    

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- Trigger name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - body -- Trigger body, you can enter it as a string or as a file, e.g., --body @triggerbody-file.json
    - operation -- The operation of the trigger.
    - type -- Trigger type
    '''
    return _call_az("az cosmosdb sql trigger update", locals())


def list(account_name, container_name, database_name, resource_group):
    '''
    List the SQL triggers under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - container_name -- Container name.
    - database_name -- Database name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql trigger list", locals())


def show(account_name, container_name, database_name, name, resource_group):
    '''
    Show the details of a SQL trigger under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- Trigger name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql trigger show", locals())


def delete(account_name, container_name, database_name, name, resource_group, yes=None):
    '''
    Delete the SQL trigger under an Azure Cosmos DB SQL container.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - container_name -- Container name.
    - database_name -- Database name.
    - name -- Trigger name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb sql trigger delete", locals())




'''
Manage Azure Active Directory service principals for automation authentication.
'''
from ... pyaz_utils import _call_az
from . import credential, owner


def create(id):
    '''
    Create a service principal.

    Required Parameters:
    - id -- identifier uri, application id, or object id of the associated application
    '''
    return _call_az("az ad sp create", locals())


def delete(id):
    '''
    Delete a service principal and its role assignments.

    Required Parameters:
    - id -- service principal name, or object id
    '''
    return _call_az("az ad sp delete", locals())


def list(all=None, display_name=None, filter=None, show_mine=None, spn=None):
    '''
    List service principals.

    Optional Parameters:
    - all -- list all entities, expect long delay if under a big organization
    - display_name -- object's display name or its prefix
    - filter -- OData filter, e.g. --filter "displayname eq 'test' and servicePrincipalType eq 'Application'"
    - show_mine -- list entities owned by the current user
    - spn -- service principal name
    '''
    return _call_az("az ad sp list", locals())


def show(id):
    '''
    Get the details of a service principal.

    Required Parameters:
    - id -- service principal name, or object id
    '''
    return _call_az("az ad sp show", locals())


def update(id, add=None, force_string=None, remove=None, set=None):
    '''
    Update a service principal

    Required Parameters:
    - id -- service principal name, or object id

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az ad sp update", locals())


def create_for_rbac(cert=None, create_cert=None, keyvault=None, name=None, role=None, scopes=None, sdk_auth=None, skip_assignment=None, years=None):
    '''
    Create a service principal and configure its access to Azure resources.

    Optional Parameters:
    - cert -- None
    - create_cert -- None
    - keyvault -- None
    - name -- None
    - role -- None
    - scopes -- None
    - sdk_auth -- output result in compatible with Azure SDK auth file
    - skip_assignment -- Skip creating the default assignment, which allows the service principal to access resources under the current subscription. When specified, --scopes will be ignored. You may use `az role assignment create` to create role assignments for this service principal later.
    - years -- None
    '''
    return _call_az("az ad sp create-for-rbac", locals())




'''
Manage Azure Advisor configuration.
'''
from ... pyaz_utils import _call_az

def list():
    '''
    List Azure Advisor configuration for the entire subscription.
    '''
    return _call_az("az advisor configuration list", locals())


def show(resource_group=None):
    '''
    Show Azure Advisor configuration for the given subscription or resource group.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az advisor configuration show", locals())


def update(add=None, configuration_name=None, exclude=None, force_string=None, include=None, low_cpu_threshold=None, remove=None, resource_group=None, set=None):
    '''
    Update Azure Advisor configuration.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - configuration_name -- Advisor configuration name. Value must be "default"
    - exclude -- Exclude from recommendation generation.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - include -- Include in recommendation generation.
    - low_cpu_threshold -- Value for low CPU threshold.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az advisor configuration update", locals())




'''
Manage service (managed) identities for a container registry
'''
from ... pyaz_utils import _call_az

def show(name, resource_group=None):
    '''
    Show the container registry's identity details

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr identity show", locals())


def assign(identities, name, resource_group=None):
    '''
    Assign a managed identity to a container registry

    Required Parameters:
    - identities -- Space-separated identities. Use '[system]' to refer to the system assigned identity
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr identity assign", locals())


def remove(identities, name, resource_group=None):
    '''
    Remove a managed identity from a container registry

    Required Parameters:
    - identities -- Space-separated identities. Use '[system]' to refer to the system assigned identity
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr identity remove", locals())




'''
Manage identity of Cognitive Services accounts.
'''
from .... pyaz_utils import _call_az

def assign(name, resource_group):
    '''
    Assign an identity of a Cognitive Services account.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account identity assign", locals())


def remove(name, resource_group):
    '''
    Remove the identity from a Cognitive Services account.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account identity remove", locals())


def show(name, resource_group):
    '''
    Show the identity of a Cognitive Services account.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account identity show", locals())




'''
Manage Azure Cosmos DB managed service identities.
'''
from ... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    Show the identities for a Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb identity show", locals())


def assign(name, resource_group, identities=None):
    '''
    Assign SystemAssigned identity for a Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to assign. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    '''
    return _call_az("az cosmosdb identity assign", locals())


def remove(name, resource_group, identities=None):
    '''
    Remove SystemAssigned identity for a Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to remove. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    '''
    return _call_az("az cosmosdb identity remove", locals())




from .... pyaz_utils import _call_az

def list(lb_name, resource_group):
    '''
    List frontend IP addresses.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb frontend-ip list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of a frontend IP address.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - name -- The name of the frontend IP configuration
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb frontend-ip show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete a frontend IP address.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - name -- The name of the frontend IP configuration
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb frontend-ip delete", locals())


def create(lb_name, name, resource_group, public_ip_address=None, public_ip_prefix=None, zone=None):
    '''
    Create a frontend IP address.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the frontend IP configuration
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - public_ip_address -- Name or ID of the existing public IP to associate with the configuration.
    - public_ip_prefix -- Name or ID of a public IP prefix.
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az network cross-region-lb frontend-ip create", locals())


def update(lb_name, name, resource_group, add=None, force_string=None, public_ip_address=None, public_ip_prefix=None, remove=None, set=None):
    '''
    Update a frontend IP address.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the frontend IP configuration
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - public_ip_address -- Name or ID of the existing public IP to associate with the configuration.
    - public_ip_prefix -- Name or ID of a public IP prefix.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network cross-region-lb frontend-ip update", locals())




from ..... pyaz_utils import _call_az

def add(action_group, name, resource_group, reset=None, strict=None, webhook_properties=None):
    '''
    Add action groups to this activity log alert. It can also be used to overwrite existing webhook properties of particular action groups.

    Required Parameters:
    - action_group -- None
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - reset -- None
    - strict -- None
    - webhook_properties -- None
    '''
    return _call_az("az monitor activity-log alert action-group add", locals())


def remove(action_group, name, resource_group):
    '''
    Remove action groups from this activity log alert

    Required Parameters:
    - action_group -- None
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor activity-log alert action-group remove", locals())




from .... pyaz_utils import _call_az

def disable(name, resource_group):
    '''
    Disable Azure Active Directly only Authentication for this Server.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql server ad-only-auth disable", locals())


def enable(name, resource_group):
    '''
    Enable Azure Active Directly only Authentication for this Server.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql server ad-only-auth enable", locals())


def get(name, resource_group):
    '''
    Get a specific Azure Active Directly only Authentication property.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql server ad-only-auth get", locals())




from .... pyaz_utils import _call_az

def create(account, compute_policy_name, object_id, object_type, max_dop_per_job=None, min_priority_per_job=None, resource_group=None):
    '''
    Create a compute policy in the Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - compute_policy_name -- None
    - object_id -- None
    - object_type -- None

    Optional Parameters:
    - max_dop_per_job -- None
    - min_priority_per_job -- None
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account compute-policy create", locals())


def update(account, compute_policy_name, max_dop_per_job=None, min_priority_per_job=None, resource_group=None):
    '''
    Update a compute policy in the Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - compute_policy_name -- None

    Optional Parameters:
    - max_dop_per_job -- None
    - min_priority_per_job -- None
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account compute-policy update", locals())


def list(account, resource_group=None):
    '''
    List compute policies in the a Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account compute-policy list", locals())


def show(account, compute_policy_name, resource_group=None):
    '''
    Retrieve a compute policy in a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - compute_policy_name -- The name of the compute policy to retrieve.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account compute-policy show", locals())


def delete(account, compute_policy_name, resource_group=None):
    '''
    Delete a compute policy in a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - compute_policy_name -- The name of the compute policy to delete.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account compute-policy delete", locals())




'''
Manage key-values stored in an App Configuration.
'''
from ... pyaz_utils import _call_az

def set(key, auth_mode=None, connection_string=None, content_type=None, endpoint=None, label=None, name=None, tags=None, value=None, yes=None):
    '''
    Set a key-value.

    Required Parameters:
    - key -- Key to be set. Key cannot be a '.' or '..', or contain the '%' character.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - content_type -- Content type of the keyvalue to be set.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - label -- If no label specified, set the key with null label by default
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - value -- Value of the keyvalue to be set.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig kv set", locals())


def delete(key, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, yes=None):
    '''
    Delete key-values.

    Required Parameters:
    - key -- Support star sign as filters, for instance * means all key and abc* means keys with abc as prefix.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - label -- If no label specified, delete entry with null label. Support star sign as filters, for instance * means all label and abc* means labels with abc as prefix.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig kv delete", locals())


def show(key, auth_mode=None, connection_string=None, datetime=None, endpoint=None, label=None, name=None):
    '''
    Show all attributes of a key-value.

    Required Parameters:
    - key -- Key to be showed.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - datetime -- Format: "YYYY-MM-DDThh:mm:ssZ". If no time zone specified, use UTC by default.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - label -- If no label specified, show entry with null label. Filtering is not supported.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    '''
    return _call_az("az appconfig kv show", locals())


def list(all=None, auth_mode=None, connection_string=None, datetime=None, endpoint=None, fields=None, key=None, label=None, name=None, resolve_keyvault=None, top=None):
    '''
    List key-values.

    Optional Parameters:
    - all -- List all items.
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - datetime -- Format: "YYYY-MM-DDThh:mm:ssZ". If no time zone specified, use UTC by default.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - fields -- Space-separated customized output fields.
    - key -- If no key specified, return all keys by default. Support star sign as filters, for instance abc* means keys with abc as prefix.
    - label -- If no label specified, list all labels. Support star sign as filters, for instance abc* means labels with abc as prefix. Use '\0' for null label.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - resolve_keyvault -- Resolve the content of key vault reference. This argument should NOT be specified along with --fields. Instead use --query for customized query.
    - top -- Maximum number of items to return. Must be a positive integer. Default to 100.
    '''
    return _call_az("az appconfig kv list", locals())


def lock(key, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, yes=None):
    '''
    Lock a key-value to prohibit write operations.

    Required Parameters:
    - key -- Key to be locked.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - label -- If no label specified, lock entry with null label. Filtering is not supported.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig kv lock", locals())


def unlock(key, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, yes=None):
    '''
    Unlock a key-value to gain write operations.

    Required Parameters:
    - key -- Key to be unlocked.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - label -- If no label specified, unlock entry with null label. Filtering is not supported.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig kv unlock", locals())


def restore(datetime, auth_mode=None, connection_string=None, endpoint=None, key=None, label=None, name=None, yes=None):
    '''
    Restore key-values.

    Required Parameters:
    - datetime -- Format: "YYYY-MM-DDThh:mm:ssZ". If no time zone specified, use UTC by default.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - key -- If no key specified, restore all keys by default. Support star sign as filters, for instance abc* means keys with abc as prefix.
    - label -- If no label specified, restore all key-value pairs with all labels. Support star sign as filters, for instance abc* means labels with abc as prefix. Use '\0' for null label.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig kv restore", locals())


def import_(source, appservice_account=None, auth_mode=None, connection_string=None, content_type=None, depth=None, endpoint=None, format=None, label=None, name=None, path=None, prefix=None, preserve_labels=None, profile=None, separator=None, skip_features=None, src_auth_mode=None, src_connection_string=None, src_endpoint=None, src_key=None, src_label=None, src_name=None, yes=None):
    '''
    Import configurations into your App Configuration from another place.

    Required Parameters:
    - source -- The source of importing. Note that importing feature flags from appservice is not supported.

    Optional Parameters:
    - appservice_account -- ARM ID for AppService OR the name of the AppService, assuming it is in the same subscription and resource group as the App Configuration. Required for AppService arguments
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - content_type -- Content type of all imported items.
    - depth -- Depth for flattening the json or yaml file to key-value pairs. Flatten to the deepest level by default if --separator is provided. Not applicable for property files or feature flags.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - format -- Imported file format. Required for file arguments. Currently, feature flags are not supported in properties format.
    - label -- Imported KVs and feature flags will be assigned with this label. If no label specified, will assign null label.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - path -- Local configuration file path. Required for file arguments.
    - prefix -- This prefix will be appended to the front of imported keys. Prefix will be ignored for feature flags.
    - preserve_labels -- Flag to preserve labels from source AppConfig. This argument should NOT be specified along with --label.
    - profile -- Import profile to be used for importing the key-values. Options 'depth', 'separator', 'content-type', 'label', 'skip-features' and, 'prefix' are not supported when using 'appconfig/kvset' profile.
    - separator -- Delimiter for flattening the json or yaml file to key-value pairs. Separator will be ignored for property files and feature flags. Supported values: '.', ',', ';', '-', '_', '__', '/', ':' 
    - skip_features -- Import only key values and exclude all feature flags. By default, all feature flags will be imported from file or appconfig. Not applicable for appservice.
    - src_auth_mode -- Auth mode for connecting to source App Configuration. For details, refer to "--auth-mode" argument.
    - src_connection_string -- Combination of access key and endpoint of the source store.
    - src_endpoint -- If --src-auth-mode is "login", provide endpoint URL of the source App Configuration.
    - src_key -- If no key specified, import all keys by default. Support star sign as filters, for instance abc* means keys with abc as prefix. Key filtering not applicable for feature flags. By default, all feature flags with specified label will be imported.
    - src_label -- Only keys with this label in source AppConfig will be imported. If no value specified, import keys with null label by default. Support star sign as filters, for instance * means all labels, abc* means labels with abc as prefix.
    - src_name -- The name of the source App Configuration.
    - yes -- Do not prompt for preview.
    '''
    return _call_az("az appconfig kv import", locals())


def export(destination, appservice_account=None, auth_mode=None, connection_string=None, dest_auth_mode=None, dest_connection_string=None, dest_endpoint=None, dest_label=None, dest_name=None, endpoint=None, format=None, key=None, label=None, name=None, naming_convention=None, path=None, prefix=None, preserve_labels=None, profile=None, resolve_keyvault=None, separator=None, skip_features=None, skip_keyvault=None, yes=None):
    '''
    Export configurations to another place from your App Configuration.

    Required Parameters:
    - destination -- The destination of exporting. Note that exporting feature flags to appservice is not supported.

    Optional Parameters:
    - appservice_account -- ARM ID for AppService OR the name of the AppService, assuming it is in the same subscription and resource group as the App Configuration. Required for AppService arguments
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - dest_auth_mode -- Auth mode for connecting to destination App Configuration. For details, refer to "--auth-mode" argument.
    - dest_connection_string -- Combination of access key and endpoint of the destination store.
    - dest_endpoint -- If --dest-auth-mode is "login", provide endpoint URL of the destination App Configuration.
    - dest_label -- Exported KVs will be labeled with this destination label. If neither --dest-label nor --preserve-labels is specified, will assign null label.
    - dest_name -- The name of the destination App Configuration.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - format -- File format exporting to. Required for file arguments. Currently, feature flags are not supported in properties format.
    - key -- If no key specified, return all keys by default. Support star sign as filters, for instance abc* means keys with abc as prefix. Key filtering not applicable for feature flags. By default, all feature flags with specified label will be exported.
    - label -- Only keys and feature flags with this label will be exported. If no label specified, export keys and feature flags with null label by default. Only when export destination is appconfig, we support star sign as filters, for instance * means all labels and abc* means labels with abc as prefix. Label filters are not supported when exporting to file or appservice.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - naming_convention -- Naming convention to be used for "Feature Management" section of file. Example: pascal = FeatureManagement, camel = featureManagement, underscore = feature_management, hyphen = feature-management.
    - path -- Local configuration file path. Required for file arguments.
    - prefix -- Prefix to be trimmed from keys. Prefix will be ignored for feature flags.
    - preserve_labels -- Flag to preserve labels from source AppConfig. This argument should NOT be specified along with --dest-label.
    - profile -- Export profile to be used for exporting the key-values. Options 'depth', 'separator', 'naming-convention', 'prefix', 'dest-label' and, 'resolve-keyvault' are not supported when using 'appconfig/kvset' profile
    - resolve_keyvault -- Resolve the content of key vault reference.
    - separator -- Delimiter for flattening the key-value pairs to json or yaml file. Required for exporting hierarchical structure. Separator will be ignored for property files and feature flags. Supported values: '.', ',', ';', '-', '_', '__', '/', ':' 
    - skip_features -- Export items excluding all feature flags. By default, all features with the specified label will be exported to file or appconfig. Not applicable for appservice.
    - skip_keyvault -- Export items excluding all key vault references. By default, all key vault references with the specified label will be exported.
    - yes -- Do not prompt for preview.
    '''
    return _call_az("az appconfig kv export", locals())


def set_keyvault(key, secret_identifier, auth_mode=None, connection_string=None, endpoint=None, label=None, name=None, tags=None, yes=None):
    '''
    Set a keyvault reference.

    Required Parameters:
    - key -- Key to be set. Key cannot be a '.' or '..', or contain the '%' character.
    - secret_identifier -- ID of the Key Vault object. Can be found using 'az keyvault {collection} show' command, where collection is key, secret or certificate. To set reference to the latest version of your secret, remove version information from secret identifier.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - label -- If no label specified, set the key with null label by default
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig kv set-keyvault", locals())




from ... pyaz_utils import _call_az

def show(scope):
    '''
    Get the details of an extension topic.

    Required Parameters:
    - scope -- The identifier of the resource to which extension topic is queried. The scope can be a subscription, or a resource group, or a top level resource belonging to a resource provider namespace. For example, use '/subscriptions/{subscriptionId}/' for a subscription, '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}' for a resource group, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}' for Azure resource.
    '''
    return _call_az("az eventgrid extension-topic show", locals())




'''
Manage applications with AAD Graph.
'''
from ... pyaz_utils import _call_az
from . import credential, owner, permission


def create(display_name, app_roles=None, available_to_other_tenants=None, credential_description=None, end_date=None, homepage=None, identifier_uris=None, key_type=None, key_usage=None, key_value=None, native_app=None, oauth2_allow_implicit_flow=None, optional_claims=None, password=None, reply_urls=None, required_resource_accesses=None, start_date=None):
    '''
    Create a web application, web API or native application

    Required Parameters:
    - display_name -- the display name of the application

    Optional Parameters:
    - app_roles -- declare the roles you want to associate with your application. Should be in manifest json format. See examples below for details
    - available_to_other_tenants -- the application can be used from any Azure AD tenants
    - credential_description -- the description of the password
    - end_date -- Date or datetime after which credentials expire(e.g. '2017-12-31T11:59:59+00:00' or '2017-12-31'). Default value is one year after current time
    - homepage -- the url where users can sign in and use your app.
    - identifier_uris -- space-separated unique URIs that Azure AD can use for this app.
    - key_type -- the type of the key credentials associated with the application
    - key_usage -- the usage of the key credentials associated with the application.
    - key_value -- the value for the key credentials associated with the application
    - native_app -- an application which can be installed on a user's device or computer
    - oauth2_allow_implicit_flow -- whether to allow implicit grant flow for OAuth2
    - optional_claims -- declare the optional claims for the application. Should be in manifest json format. See examples below for details. Please reference https://docs.microsoft.com/azure/active-directory/develop/active-directory-optional-claims#optionalclaim-type for optional claim properties.
    - password -- app password, aka 'client secret'
    - reply_urls -- space-separated URIs to which Azure AD will redirect in response to an OAuth 2.0 request. The value does not need to be a physical endpoint, but must be a valid URI.
    - required_resource_accesses -- resource scopes and roles the application requires access to. Should be in manifest json format. See examples below for details
    - start_date -- Date or datetime at which credentials become valid(e.g. '2017-01-01T01:00:00+00:00' or '2017-01-01'). Default value is current time
    '''
    return _call_az("az ad app create", locals())


def delete(id):
    '''
    Delete an application.

    Required Parameters:
    - id -- identifier uri, application id, or object id
    '''
    return _call_az("az ad app delete", locals())


def list(all=None, app_id=None, display_name=None, filter=None, identifier_uri=None, show_mine=None):
    '''
    List applications.

    Optional Parameters:
    - all -- list all entities, expect long delay if under a big organization
    - app_id -- application id
    - display_name -- the display name of the application
    - filter -- OData filter, e.g. --filter "displayname eq 'test' and servicePrincipalType eq 'Application'"
    - identifier_uri -- graph application identifier, must be in uri format
    - show_mine -- list entities owned by the current user
    '''
    return _call_az("az ad app list", locals())


def show(id):
    '''
    Get the details of an application.

    Required Parameters:
    - id -- identifier uri, application id, or object id
    '''
    return _call_az("az ad app show", locals())


def update(id, add=None, app_roles=None, available_to_other_tenants=None, credential_description=None, display_name=None, end_date=None, force_string=None, homepage=None, identifier_uris=None, key_type=None, key_usage=None, key_value=None, oauth2_allow_implicit_flow=None, optional_claims=None, password=None, remove=None, reply_urls=None, required_resource_accesses=None, set=None, start_date=None):
    '''
    Update an application.

    Required Parameters:
    - id -- identifier uri, application id, or object id

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - app_roles -- declare the roles you want to associate with your application. Should be in manifest json format. See examples below for details
    - available_to_other_tenants -- the application can be used from any Azure AD tenants
    - credential_description -- the description of the password
    - display_name -- the display name of the application
    - end_date -- Date or datetime after which credentials expire(e.g. '2017-12-31T11:59:59+00:00' or '2017-12-31'). Default value is one year after current time
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - homepage -- the url where users can sign in and use your app.
    - identifier_uris -- space-separated unique URIs that Azure AD can use for this app.
    - key_type -- the type of the key credentials associated with the application
    - key_usage -- the usage of the key credentials associated with the application.
    - key_value -- the value for the key credentials associated with the application
    - oauth2_allow_implicit_flow -- whether to allow implicit grant flow for OAuth2
    - optional_claims -- declare the optional claims for the application. Should be in manifest json format. See examples below for details. Please reference https://docs.microsoft.com/azure/active-directory/develop/active-directory-optional-claims#optionalclaim-type for optional claim properties.
    - password -- app password, aka 'client secret'
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - reply_urls -- space-separated URIs to which Azure AD will redirect in response to an OAuth 2.0 request. The value does not need to be a physical endpoint, but must be a valid URI.
    - required_resource_accesses -- resource scopes and roles the application requires access to. Should be in manifest json format. See examples below for details
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - start_date -- Date or datetime at which credentials become valid(e.g. '2017-01-01T01:00:00+00:00' or '2017-01-01'). Default value is current time
    '''
    return _call_az("az ad app update", locals())




from .... pyaz_utils import _call_az

def show(account_name, resource_group=None):
    '''
    Show the properties of file service in storage account.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account file-service-properties show", locals())


def update(account_name, add=None, auth_methods=None, channel_encryption=None, delete_retention_days=None, enable_delete_retention=None, enable_smb_multichannel=None, force_string=None, kerb_ticket_encryption=None, remove=None, resource_group=None, set=None, versions=None):
    '''
    Update the properties of file service in storage account.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - auth_methods -- SMB authentication methods supported by server. Valid values are NTLMv2, Kerberos. Should be passed as a string with delimiter ';'.
    - channel_encryption -- SMB channel encryption supported by server. Valid values are AES-128-CCM, AES-128-GCM, AES-256-GCM. Should be passed as a string with delimiter ';' 
    - delete_retention_days -- Indicate the number of days that the deleted item should be retained. The minimum specified value can be 1 and the maximum value can be 365.
    - enable_delete_retention -- Enable file service properties for share soft delete.
    - enable_smb_multichannel -- Set SMB Multichannel setting for file service. Applies to Premium FileStorage only.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - kerb_ticket_encryption -- Kerberos ticket encryption supported by server. Valid values are RC4-HMAC, AES-256. Should be passed as a string with delimiter ';'.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - versions -- SMB protocol versions supported by server. Valid values are SMB2.1, SMB3.0, SMB3.1.1. Should be passed as a string with delimiter ';'.
    '''
    return _call_az("az storage account file-service-properties update", locals())




'''
Manage the route server.
'''
from ... pyaz_utils import _call_az
from . import peering


def create(hosted_subnet, name, resource_group, location=None, public_ip_address=None, tags=None):
    '''
    Create a route server.

    Required Parameters:
    - hosted_subnet -- The ID of a subnet where Route Server would be deployed
    - name -- The name of the Route Server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - public_ip_address -- The name or ID of the public IP address.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network routeserver create", locals())


def update(name, resource_group, add=None, allow_b2b_traffic=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a route server.

    Required Parameters:
    - name -- The name of the Route Server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - allow_b2b_traffic -- Allow branch to branch traffic.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network routeserver update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a route server under a resource group.

    Required Parameters:
    - name -- The name of the Route Server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network routeserver delete", locals())


def show(name, resource_group):
    '''
    Show a route server.

    Required Parameters:
    - name -- The name of the Route Server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network routeserver show", locals())


def list(resource_group=None):
    '''
    List all route servers under a subscription or a resource group.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network routeserver list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the route server is met.

    Required Parameters:
    - name -- The name of the Route Server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network routeserver wait", locals())




'''
Manage transform outputs for an Azure Media Services account.
'''
from .... pyaz_utils import _call_az

def add(account_name, name, preset, resource_group, audio_analysis_mode=None, audio_language=None, insights_to_extract=None, on_error=None, relative_priority=None, resolution=None, video_analysis_mode=None):
    '''
    Add an output to an existing transform.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the transform.
    - preset -- Preset that describes the operations that will be used to modify, transcode, or extract insights from the source file to generate the transform output. Allowed values: H264SingleBitrateSD, H264SingleBitrate720p, H264SingleBitrate1080p, AdaptiveStreaming, AACGoodQualityAudio, ContentAwareEncodingExperimental, ContentAwareEncoding, CopyAllBitrateNonInterleaved, H264MultipleBitrate1080p, H264MultipleBitrate720p, H264MultipleBitrateSD, H265ContentAwareEncoding, H265AdaptiveStreaming, H265SingleBitrate720p, H265SingleBitrate1080p, H265SingleBitrate4K, AudioAnalyzer, VideoAnalyzer, FaceDetector. In addition to the allowed values, you can also pass a path to a custom Standard Encoder preset JSON file. See https://docs.microsoft.com/rest/api/media/transforms/createorupdate#standardencoderpreset for further details on the settings to use to build a custom preset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - audio_analysis_mode -- Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen. Allowed values: Standard, Basic.
    - audio_language -- The language for the audio payload in the input using the BCP-47 format of "language tag-region" (e.g: en-US). If not specified, automatic language detection would be employed. This feature currently supports English, Chinese, French, German, Italian, Japanese, Spanish, Russian, and Portuguese. The automatic detection works best with audio recordings with clearly discernable speech. If automatic detection fails to find the language, transcription would fallback to English. Allowed values: en-US, en-GB, es-ES, es-MX, fr-FR, it-IT, ja-JP, pt-BR, zh-CN, de-DE, ar-EG, ru-RU, hi-IN.
    - insights_to_extract -- The type of insights to be extracted. If not set then the type will be selected based on the content type. If the content is audio only then only audio insights will be extracted and if it is video only video insights will be extracted.
    - on_error -- A Transform can define more than one output. This property defines what the service should do when one output fails - either continue to produce other outputs, or, stop the other outputs. The overall Job state will not reflect failures of outputs that are specified with 'ContinueJob'. The default is 'StopProcessingJob'.
    - relative_priority -- Sets the relative priority of the transform outputs within a transform. This sets the priority that the service uses for processing TransformOutputs. The default priority is Normal.
    - resolution -- Specifies the maximum resolution at which your video is analyzed. The default behavior is "SourceResolution," which will keep the input video at its original resolution when analyzed. Using StandardDefinition will resize input videos to standard definition while preserving the appropriate aspect ratio. It will only resize if the video is of higher resolution. For example, a 1920x1080 input would be scaled to 640x360 before processing. Switching to "StandardDefinition" will reduce the time it takes to process high resolution video. It may also reduce the cost of using this component (see https://azure.microsoft.com/pricing/details/media-services/#analytics for details). However, faces that end up being too small in the resized video may not be detected. Allowed values: StandardDefinition, SourceResolution.
    - video_analysis_mode -- Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen. Allowed values: Standard, Basic
    '''
    return _call_az("az ams transform output add", locals())


def remove(account_name, name, output_index, resource_group):
    '''
    Remove an output from an existing transform.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the transform.
    - output_index -- The element index of the output to remove.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams transform output remove", locals())




from ... pyaz_utils import _call_az

def list(cluster_name, resource_group):
    '''
    List managed applications of a given managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-application list", locals())


def delete(cluster_name, name, resource_group):
    '''
    Delete a managed application.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-application delete", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the properties of a managed application on an Azure Service Fabric managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-application show", locals())


def create(cluster_name, name, resource_group, type_name, version, package_url=None, parameters=None, tags=None):
    '''
    Create a new managed application on an Azure Service Fabric managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - type_name -- Specify the application type name.
    - version -- Specify the application type version.

    Optional Parameters:
    - package_url -- Specify the url of the application package sfpkg file.
    - parameters -- Specify the application parameters as key/value pairs. These parameters must exist in the application manifest. for example: --application-parameters param1=value1 param2=value2
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sf managed-application create", locals())


def update(cluster_name, name, resource_group, failure_action=None, force_restart=None, hc_retry_timeout=None, hc_stable_duration=None, hc_wait_duration=None, instance_close_delay_duration=None, max_percent_unhealthy_deployed_applications=None, max_percent_unhealthy_partitions=None, max_percent_unhealthy_replicas=None, max_percent_unhealthy_services=None, parameters=None, recreate_application=None, service_type_health_policy_map=None, tags=None, ud_timeout=None, upgrade_mode=None, upgrade_replica_set_check_timeout=None, upgrade_timeout=None, version=None, warning_as_error=None):
    '''
    Update a Azure Service Fabric managed application.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - failure_action -- Specify the action to take if the monitored upgrade fails. The acceptable values for this parameter are Rollback or Manual.
    - force_restart -- Indicates that the service host restarts even if the upgrade is a configuration-only change.
    - hc_retry_timeout -- Specify the duration, in seconds, after which Service Fabric retries the health check if the previous health check fails.
    - hc_stable_duration -- Specify the duration, in seconds, that Service Fabric waits in order to verify that the application is stable before moving to the next upgrade domain or completing the upgrade. This wait duration prevents undetected changes of health right after the health check is performed.
    - hc_wait_duration -- Specify the duration, in seconds, that Service Fabric waits before it performs the initial health check after it finishes the upgrade on the upgrade domain.
    - instance_close_delay_duration -- Specify the duration in seconds, to wait before a stateless instance is closed, to allow the active requests to drain gracefully. This would be effective when the instance is closing during the application/cluster upgrade, only for those instances which have a non-zero delay duration configured in the service description.
    - max_percent_unhealthy_deployed_applications -- Specify the maximum percentage of the application instances deployed on the nodes in the cluster that have a health state of error before the application health state for the cluster is error. Allowed values are form 0 to 100.
    - max_percent_unhealthy_partitions -- Specify the maximum percent of unhelthy partitions per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.
    - max_percent_unhealthy_replicas -- Specify the maximum percent of unhelthy replicas per service allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.
    - max_percent_unhealthy_services -- Specify the maximum percent of unhelthy services allowed by the health policy for the default service type to use for the monitored upgrade. Allowed values are from 0 to 100.
    - parameters -- Specify the application parameters as key/value pairs. These parameters must exist in the application manifest. for example: --application-parameters param1=value1 param2=value2
    - recreate_application -- Determines whether the application should be recreated on update. If value=true, the rest of the upgrade policy parameters are not allowed.
    - service_type_health_policy_map -- Specify the map of the health policy to use for different service types as key/value pairs in the following format: "ServiceTypeName"="MaxPercentUnhealthyPartitionsPerService,MaxPercentUnhealthyReplicasPerPartition,MaxPercentUnhealthyServices". for example: --service-type-health-policy-map "ServiceTypeName01"="5,10,5" "ServiceTypeName02"="5,5,5"
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - ud_timeout -- Specify the maximum time, in seconds, that Service Fabric takes to upgrade a single upgrade domain. After this period, the upgrade fails.
    - upgrade_mode -- Specify the mode used to monitor health during a rolling upgrade. The values are Monitored, and UnmonitoredAuto.
    - upgrade_replica_set_check_timeout -- Specify the maximum time, in seconds, that Service Fabric waits for a service to reconfigure into a safe state, if not already in a safe state, before Service Fabric proceeds with the upgrade.
    - upgrade_timeout -- Specify the maximum time, in seconds, that Service Fabric takes for the entire upgrade. After this period, the upgrade fails.
    - version -- Specify the application type version.
    - warning_as_error -- Indicates whether to treat a warning health event as an error event during health evaluation.
    '''
    return _call_az("az sf managed-application update", locals())




'''
Manage Data Lake Analytics catalogs.
'''
from ... pyaz_utils import _call_az
from . import assembly, credential, database, external_data_source, package, procedure, schema, table, table_partition, table_stats, table_type, tvf, view




from .... pyaz_utils import _call_az

def list(name, resource_group, slot=None):
    '''
    Get a web app's connection strings.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config connection-string list", locals())


def set(connection_string_type, name, resource_group, settings=None, slot=None, slot_settings=None):
    '''
    Update a web app's connection strings.

    Required Parameters:
    - connection_string_type -- connection string type
    - name -- Name of the web app. You can configure the default using `az configure --defaults web=<name>`. If `--ids` is provided this should NOT be specified.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - settings -- space-separated connection-string in a format of `<name>=<value>`
    - slot -- the name of the slot. Default to the productions slot if not specified
    - slot_settings -- space-separated slot connection-string in a format of either `<name>=<value>` or `@<json_file>`
    '''
    return _call_az("az webapp config connection-string set", locals())


def delete(name, resource_group, setting_names, slot=None):
    '''
    Delete a web app's connection strings.

    Required Parameters:
    - name -- Name of the web app. You can configure the default using `az configure --defaults web=<name>`. If `--ids` is provided this should NOT be specified.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - setting_names -- space-separated connection-string names

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config connection-string delete", locals())




'''
Manage Azure subscription information.
'''
from .. pyaz_utils import _call_az
from . import lock, management_group


def list(all=None, refresh=None):
    '''
    Get a list of subscriptions for the logged in account. By default, only 'Enabled' subscriptions from the current cloud is shown.

    Optional Parameters:
    - all -- List all subscriptions from all clouds, rather than just 'Enabled' ones
    - refresh -- retrieve up-to-date subscriptions from server
    '''
    return _call_az("az account list", locals())


def set(subscription):
    '''
    Set a subscription to be the current active subscription.

    Required Parameters:
    - subscription -- Name or ID of subscription.
    '''
    return _call_az("az account set", locals())


def show(sdk_auth=None, subscription=None):
    '''
    Get the details of a subscription.

    Optional Parameters:
    - sdk_auth -- Output result to a file compatible with Azure SDK auth. Only applicable when authenticating with a Service Principal.
    - subscription -- Name or ID of subscription.
    '''
    return _call_az("az account show", locals())


def clear():
    '''
    Clear all subscriptions from the CLI's local cache.
    '''
    return _call_az("az account clear", locals())


def list_locations():
    '''
    List supported regions for the current subscription.
    '''
    return _call_az("az account list-locations", locals())


def get_access_token(resource=None, resource_type=None, scope=None, subscription=None, tenant=None):
    '''
    Get a token for utilities to access Azure.

    Optional Parameters:
    - resource -- Azure resource endpoints in AAD v1.0.
    - resource_type -- Type of well-known resource.
    - scope -- Space-separated AAD scopes in AAD v2.0. Default to Azure Resource Manager.
    - subscription -- Name or ID of subscription.
    - tenant -- Tenant ID for which the token is acquired. Only available for user and service principal account, not for MSI or Cloud Shell account
    '''
    return _call_az("az account get-access-token", locals())




'''
Manage HDInsight cluster's virtual hosts.
'''
from ... pyaz_utils import _call_az

def list(cluster_name, resource_group):
    '''
    List the hosts of the specified HDInsight cluster.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight host list", locals())


def restart(cluster_name, host_names, resource_group, yes=None):
    '''
    Restart the specific hosts of the specified HDInsight cluster.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - host_names -- A space-delimited list of host names that need to be restarted.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az hdinsight host restart", locals())




'''
Manage Azure Network resources.
'''
from .. pyaz_utils import _call_az
from . import application_gateway, asg, bastion, cross_region_lb, ddos_protection, dns, express_route, lb, local_gateway, nic, nsg, private_endpoint, private_endpoint_connection, private_link_resource, private_link_service, profile, public_ip, route_filter, route_table, routeserver, security_partner_provider, service_endpoint, virtual_appliance, vnet, vnet_gateway, vpn_connection, vrouter, watcher


def list_usages(location):
    '''
    List the number of network resources in a region that are used against a subscription quota.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network list-usages", locals())


def list_service_tags(location):
    '''
    List all service tags which are below to different resources

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network list-service-tags", locals())


def list_service_aliases(location, resource_group=None):
    '''
    List available service aliases in the region which can be used for Service Endpoint Policies.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network list-service-aliases", locals())




'''
Get provider operations metadatas.
'''
from ... pyaz_utils import _call_az

def list():
    '''
    Get operations from all providers.
    '''
    return _call_az("az provider operation list", locals())


def show(namespace):
    '''
    Get an individual provider's operations.

    Required Parameters:
    - namespace -- the resource namespace, aka 'provider'
    '''
    return _call_az("az provider operation show", locals())




from ... pyaz_utils import _call_az

def delete(name, resource_group, no_wait=None):
    '''
    Delete a virtual cluster.

    Required Parameters:
    - name -- The virtual cluster name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql virtual-cluster delete", locals())


def show(name, resource_group):
    '''
    Get the details for a virtual cluster.

    Required Parameters:
    - name -- The virtual cluster name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql virtual-cluster show", locals())


def list(resource_group=None):
    '''
    List available virtual clusters.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql virtual-cluster list", locals())




'''
Manage Azure Marketplace image terms.
'''
from .... pyaz_utils import _call_az

def accept(offer=None, plan=None, publisher=None, urn=None):
    '''
    Accept Azure Marketplace image terms so that the image can be used to create VMs.

    Optional Parameters:
    - offer -- Image offer
    - plan -- Image billing plan
    - publisher -- Image publisher
    - urn -- URN, in the format of 'publisher:offer:sku:version'. If specified, other argument values can be omitted
    '''
    return _call_az("az vm image terms accept", locals())


def cancel(offer=None, plan=None, publisher=None, urn=None):
    '''
    Cancel Azure Marketplace image terms.

    Optional Parameters:
    - offer -- Image offer
    - plan -- Image billing plan
    - publisher -- Image publisher
    - urn -- URN, in the format of 'publisher:offer:sku:version'. If specified, other argument values can be omitted
    '''
    return _call_az("az vm image terms cancel", locals())


def show(offer=None, plan=None, publisher=None, urn=None):
    '''
    Get the details of Azure Marketplace image terms.

    Optional Parameters:
    - offer -- Image offer
    - plan -- Image billing plan
    - publisher -- Image publisher
    - urn -- URN, in the format of 'publisher:offer:sku:version'. If specified, other argument values can be omitted
    '''
    return _call_az("az vm image terms show", locals())




from .... pyaz_utils import _call_az

def show(name, resource_group, slot=None):
    '''
    Show Access Restriction settings for webapp.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config access-restriction show", locals())


def add(name, priority, resource_group, action=None, description=None, http_headers=None, ignore_missing_endpoint=None, ip_address=None, rule_name=None, scm_site=None, service_tag=None, slot=None, subnet=None, vnet_name=None, vnet_resource_group=None):
    '''
    Adds an Access Restriction to the webapp.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - priority -- Priority of the access restriction rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - action -- Allow or deny access
    - description -- Description of the access restriction rule
    - http_headers -- space-separated http headers in a format of `<name>=<value>`
    - ignore_missing_endpoint -- Create access restriction rule with checking if the subnet has Microsoft.Web service endpoint enabled
    - ip_address -- IP address or CIDR range (optional comma separated list of up to 8 ranges)
    - rule_name -- Name of the access restriction rule to add
    - scm_site -- True if access restrictions is added for scm site
    - service_tag -- Service Tag (optional comma separated list of up to 8 tags)
    - slot -- the name of the slot. Default to the productions slot if not specified
    - subnet -- Subnet name (requires vNet name) or subnet resource id
    - vnet_name -- vNet name
    - vnet_resource_group -- Resource group of virtual network (default is web app resource group)
    '''
    return _call_az("az webapp config access-restriction add", locals())


def remove(name, resource_group, action=None, ip_address=None, rule_name=None, scm_site=None, service_tag=None, slot=None, subnet=None, vnet_name=None):
    '''
    Removes an Access Restriction from the webapp.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - action -- Allow or deny access
    - ip_address -- IP address or CIDR range (optional comma separated list of up to 8 ranges)
    - rule_name -- Name of the access restriction to remove
    - scm_site -- True if access restriction should be removed from scm site
    - service_tag -- Service Tag (optional comma separated list of up to 8 tags)
    - slot -- the name of the slot. Default to the productions slot if not specified
    - subnet -- Subnet name (requires vNet name) or subnet resource id
    - vnet_name -- vNet name
    '''
    return _call_az("az webapp config access-restriction remove", locals())


def set(name, resource_group, use_same_restrictions_for_scm_site, slot=None):
    '''
    Sets if SCM site is using the same restrictions as the main site.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - use_same_restrictions_for_scm_site -- Use same access restrictions for scm site

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config access-restriction set", locals())




from ... pyaz_utils import _call_az

def create(account_endpoint=None, account_key=None, account_name=None, do_not_run_after=None, do_not_run_until=None, id=None, job_manager_task_command_line=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None, recurrence_interval=None, required_slots=None, start_window=None, uses_task_dependencies=None):
    '''
    Add a Batch job schedule to an account.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - do_not_run_after -- If you do not specify a doNotRunAfter time, and you are creating a recurring Job Schedule, the Job Schedule will remain active until you explicitly terminate it. Expected format is an ISO-8601 timestamp.
    - do_not_run_until -- If you do not specify a doNotRunUntil time, the schedule becomes ready to create Jobs immediately. Expected format is an ISO-8601 timestamp.
    - id -- Required. The ID can contain any combination of alphanumeric characters including hyphens and underscores, and cannot contain more than 64 characters. The ID is case-preserving and case-insensitive (that is, you may not have two IDs within an Account that differ only by case).
    - job_manager_task_command_line -- Required. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux. If the command line refers to file paths, it should use a relative path (relative to the Task working directory), or use the Batch provided environment variable (https://docs.microsoft.com/en-us/azure/batch/batch-compute-node-environment-variables).
    - job_manager_task_id -- Required. The ID can contain any combination of alphanumeric characters including hyphens and underscores and cannot contain more than 64 characters.
    - job_manager_task_resource_files -- Files listed under this element are located in the Task's working directory. There is a maximum size for the list of resource files.  When the max size is exceeded, the request will fail and the response error code will be RequestEntityTooLarge. If this occurs, the collection of ResourceFiles must be reduced in size. This can be achieved using .zip files, Application Packages, or Docker Containers. Space-separated resource references in filename=httpurl format.
    - job_max_task_retry_count -- The maximum number of times each Task may be retried. The Batch service retries a Task if its exit code is nonzero. Note that this value specifically controls the number of retries. The Batch service will try each Task once, and may then retry up to this limit. For example, if the maximum retry count is 3, Batch tries a Task up to 4 times (one initial try and 3 retries). If the maximum retry count is 0, the Batch service does not retry Tasks. If the maximum retry count is -1, the Batch service retries Tasks without limit. The default value is 0 (no retries).
    - job_max_wall_clock_time -- If the Job does not complete within the time limit, the Batch service terminates it and any Tasks that are still running. In this case, the termination reason will be MaxWallClockTimeExpiry. If this property is not specified, there is no time limit on how long the Job may run. Expected format is an ISO-8601 duration.
    - json_file -- A file containing the cloud job schedule specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Cloud Job Schedule Arguments' are ignored.
    - max_parallel_tasks -- The maximum number of tasks that can be executed in parallel for the job. The value of maxParallelTasks must be -1 or greater than 0 if specified. If not specified, the default value is -1, which means there's no limit to the number of tasks that can be run at once. You can update a job's maxParallelTasks after it has been created using the update job API. Default value: -1 .
    - metadata -- The Batch service does not assign any meaning to metadata; it is solely for the use of user code. Space-separated values in 'key=value' format.
    - on_all_tasks_complete -- The action the Batch service should take when all Tasks in a Job created under this schedule are in the completed state. Note that if a Job contains no Tasks, then all Tasks are considered complete. This option is therefore most commonly used with a Job Manager task; if you want to use automatic Job termination without a Job Manager, you should initially set onAllTasksComplete to noaction and update the Job properties to set onAllTasksComplete to terminatejob once you have finished adding Tasks. The default is noaction.
    - pool_id -- The id of an existing pool. All the tasks of the job will run on the specified pool.
    - priority -- The priority of Jobs created under this schedule. Priority values can range from -1000 to 1000, with -1000 being the lowest priority and 1000 being the highest priority. The default value is 0. This priority is used as the default for all Jobs under the Job Schedule. You can update a Job's priority after it has been created using by using the update Job API.
    - recurrence_interval -- Because a Job Schedule can have at most one active Job under it at any given time, if it is time to create a new Job under a Job Schedule, but the previous Job is still running, the Batch service will not create the new Job until the previous Job finishes. If the previous Job does not finish within the startWindow period of the new recurrenceInterval, then no new Job will be scheduled for that interval. For recurring Jobs, you should normally specify a jobManagerTask in the jobSpecification. If you do not use jobManagerTask, you will need an external process to monitor when Jobs are created, add Tasks to the Jobs and terminate the Jobs ready for the next recurrence. The default is that the schedule does not recur: one Job is created, within the startWindow after the doNotRunUntil time, and the schedule is complete as soon as that Job finishes. The minimum value is 1 minute. If you specify a lower value, the Batch service rejects the schedule with an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    - required_slots -- The number of scheduling slots that the Task requires to run. The default is 1. A Task can only be scheduled to run on a compute node if the node has enough free scheduling slots available. For multi-instance Tasks, this property is not supported and must not be specified.
    - start_window -- If a Job is not created within the startWindow interval, then the 'opportunity' is lost; no Job will be created until the next recurrence of the schedule. If the schedule is recurring, and the startWindow is longer than the recurrence interval, then this is equivalent to an infinite startWindow, because the Job that is 'due' in one recurrenceInterval is not carried forward into the next recurrence interval. The default is infinite. The minimum value is 1 minute. If you specify a lower value, the Batch service rejects the schedule with an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    - uses_task_dependencies -- Whether Tasks in the Job can define dependencies on each other. The default is false. True if flag present.
    '''
    return _call_az("az batch job-schedule create", locals())


def delete(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    '''
    

    Required Parameters:
    - job_schedule_id -- The ID of the Job Schedule to delete.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch job-schedule delete", locals())


def show(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    '''
    

    Required Parameters:
    - job_schedule_id -- The ID of the Job Schedule to get.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand -- An OData $expand clause.
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch job-schedule show", locals())


def set(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, do_not_run_after=None, do_not_run_until=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_manager_task_application_package_references=None, job_manager_task_command_line=None, job_manager_task_environment_settings=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_metadata=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None, recurrence_interval=None, required_slots=None, start_window=None, uses_task_dependencies=None):
    '''
    Update the properties of a job schedule.

    Required Parameters:
    - job_schedule_id -- The ID of the Job Schedule to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - do_not_run_after -- If you do not specify a doNotRunAfter time, and you are creating a recurring Job Schedule, the Job Schedule will remain active until you explicitly terminate it. Expected format is an ISO-8601 timestamp.
    - do_not_run_until -- If you do not specify a doNotRunUntil time, the schedule becomes ready to create Jobs immediately. Expected format is an ISO-8601 timestamp.
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - job_manager_task_application_package_references -- Application Packages are downloaded and deployed to a shared directory, not the Task working directory. Therefore, if a referenced Application Package is already on the Compute Node, and is up to date, then it is not re-downloaded; the existing copy on the Compute Node is used. If a referenced Application Package cannot be installed, for example because the package has been deleted or because download failed, the Task fails. Space-separated application IDs with optional version in 'id[#version]' format.
    - job_manager_task_command_line -- Required. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux. If the command line refers to file paths, it should use a relative path (relative to the Task working directory), or use the Batch provided environment variable (https://docs.microsoft.com/en-us/azure/batch/batch-compute-node-environment-variables).
    - job_manager_task_environment_settings --  Space-separated values in 'key=value' format.
    - job_manager_task_id -- Required. The ID can contain any combination of alphanumeric characters including hyphens and underscores and cannot contain more than 64 characters.
    - job_manager_task_resource_files -- Files listed under this element are located in the Task's working directory. There is a maximum size for the list of resource files.  When the max size is exceeded, the request will fail and the response error code will be RequestEntityTooLarge. If this occurs, the collection of ResourceFiles must be reduced in size. This can be achieved using .zip files, Application Packages, or Docker Containers. Space-separated resource references in filename=httpurl format.
    - job_metadata -- The Batch service does not assign any meaning to metadata; it is solely for the use of user code. Space-separated values in 'key=value' format.
    - json_file -- A file containing the job schedule patch parameter specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Job Schedule Arguments' are ignored.
    - max_parallel_tasks -- The maximum number of tasks that can be executed in parallel for the job. The value of maxParallelTasks must be -1 or greater than 0 if specified. If not specified, the default value is -1, which means there's no limit to the number of tasks that can be run at once. You can update a job's maxParallelTasks after it has been created using the update job API. Default value: -1 .
    - metadata -- If you do not specify this element, existing metadata is left unchanged. Space-separated values in 'key=value' format.
    - on_all_tasks_complete -- The action the Batch service should take when all Tasks in a Job created under this schedule are in the completed state. Note that if a Job contains no Tasks, then all Tasks are considered complete. This option is therefore most commonly used with a Job Manager task; if you want to use automatic Job termination without a Job Manager, you should initially set onAllTasksComplete to noaction and update the Job properties to set onAllTasksComplete to terminatejob once you have finished adding Tasks. The default is noaction.
    - pool_id -- The id of an existing pool. All the tasks of the job will run on the specified pool.
    - priority -- The priority of Jobs created under this schedule. Priority values can range from -1000 to 1000, with -1000 being the lowest priority and 1000 being the highest priority. The default value is 0. This priority is used as the default for all Jobs under the Job Schedule. You can update a Job's priority after it has been created using by using the update Job API.
    - recurrence_interval -- Because a Job Schedule can have at most one active Job under it at any given time, if it is time to create a new Job under a Job Schedule, but the previous Job is still running, the Batch service will not create the new Job until the previous Job finishes. If the previous Job does not finish within the startWindow period of the new recurrenceInterval, then no new Job will be scheduled for that interval. For recurring Jobs, you should normally specify a jobManagerTask in the jobSpecification. If you do not use jobManagerTask, you will need an external process to monitor when Jobs are created, add Tasks to the Jobs and terminate the Jobs ready for the next recurrence. The default is that the schedule does not recur: one Job is created, within the startWindow after the doNotRunUntil time, and the schedule is complete as soon as that Job finishes. The minimum value is 1 minute. If you specify a lower value, the Batch service rejects the schedule with an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    - required_slots -- The number of scheduling slots that the Task requires to run. The default is 1. A Task can only be scheduled to run on a compute node if the node has enough free scheduling slots available. For multi-instance Tasks, this property is not supported and must not be specified.
    - start_window -- If a Job is not created within the startWindow interval, then the 'opportunity' is lost; no Job will be created until the next recurrence of the schedule. If the schedule is recurring, and the startWindow is longer than the recurrence interval, then this is equivalent to an infinite startWindow, because the Job that is 'due' in one recurrenceInterval is not carried forward into the next recurrence interval. The default is infinite. The minimum value is 1 minute. If you specify a lower value, the Batch service rejects the schedule with an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    - uses_task_dependencies -- Whether Tasks in the Job can define dependencies on each other. The default is false. Specify either 'true' or 'false' to update the property.
    '''
    return _call_az("az batch job-schedule set", locals())


def reset(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, do_not_run_after=None, do_not_run_until=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_manager_task_application_package_references=None, job_manager_task_command_line=None, job_manager_task_environment_settings=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_metadata=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None, recurrence_interval=None, required_slots=None, start_window=None, uses_task_dependencies=None):
    '''
    Reset the properties of a job schedule.  An updated job specification only applies to new jobs.

    Required Parameters:
    - job_schedule_id -- The ID of the Job Schedule to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - do_not_run_after -- If you do not specify a doNotRunAfter time, and you are creating a recurring Job Schedule, the Job Schedule will remain active until you explicitly terminate it. Expected format is an ISO-8601 timestamp.
    - do_not_run_until -- If you do not specify a doNotRunUntil time, the schedule becomes ready to create Jobs immediately. Expected format is an ISO-8601 timestamp.
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - job_manager_task_application_package_references -- Application Packages are downloaded and deployed to a shared directory, not the Task working directory. Therefore, if a referenced Application Package is already on the Compute Node, and is up to date, then it is not re-downloaded; the existing copy on the Compute Node is used. If a referenced Application Package cannot be installed, for example because the package has been deleted or because download failed, the Task fails. Space-separated application IDs with optional version in 'id[#version]' format.
    - job_manager_task_command_line -- Required. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux. If the command line refers to file paths, it should use a relative path (relative to the Task working directory), or use the Batch provided environment variable (https://docs.microsoft.com/en-us/azure/batch/batch-compute-node-environment-variables).
    - job_manager_task_environment_settings --  Space-separated values in 'key=value' format.
    - job_manager_task_id -- Required. The ID can contain any combination of alphanumeric characters including hyphens and underscores and cannot contain more than 64 characters.
    - job_manager_task_resource_files -- Files listed under this element are located in the Task's working directory. There is a maximum size for the list of resource files.  When the max size is exceeded, the request will fail and the response error code will be RequestEntityTooLarge. If this occurs, the collection of ResourceFiles must be reduced in size. This can be achieved using .zip files, Application Packages, or Docker Containers. Space-separated resource references in filename=httpurl format.
    - job_metadata -- The Batch service does not assign any meaning to metadata; it is solely for the use of user code. Space-separated values in 'key=value' format.
    - json_file -- A file containing the job schedule update parameter specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Job Schedule Arguments' are ignored.
    - max_parallel_tasks -- The maximum number of tasks that can be executed in parallel for the job. The value of maxParallelTasks must be -1 or greater than 0 if specified. If not specified, the default value is -1, which means there's no limit to the number of tasks that can be run at once. You can update a job's maxParallelTasks after it has been created using the update job API. Default value: -1 .
    - metadata -- If you do not specify this element, it takes the default value of an empty list; in effect, any existing metadata is deleted. Space-separated values in 'key=value' format.
    - on_all_tasks_complete -- The action the Batch service should take when all Tasks in a Job created under this schedule are in the completed state. Note that if a Job contains no Tasks, then all Tasks are considered complete. This option is therefore most commonly used with a Job Manager task; if you want to use automatic Job termination without a Job Manager, you should initially set onAllTasksComplete to noaction and update the Job properties to set onAllTasksComplete to terminatejob once you have finished adding Tasks. The default is noaction.
    - pool_id -- The id of an existing pool. All the tasks of the job will run on the specified pool.
    - priority -- The priority of Jobs created under this schedule. Priority values can range from -1000 to 1000, with -1000 being the lowest priority and 1000 being the highest priority. The default value is 0. This priority is used as the default for all Jobs under the Job Schedule. You can update a Job's priority after it has been created using by using the update Job API.
    - recurrence_interval -- Because a Job Schedule can have at most one active Job under it at any given time, if it is time to create a new Job under a Job Schedule, but the previous Job is still running, the Batch service will not create the new Job until the previous Job finishes. If the previous Job does not finish within the startWindow period of the new recurrenceInterval, then no new Job will be scheduled for that interval. For recurring Jobs, you should normally specify a jobManagerTask in the jobSpecification. If you do not use jobManagerTask, you will need an external process to monitor when Jobs are created, add Tasks to the Jobs and terminate the Jobs ready for the next recurrence. The default is that the schedule does not recur: one Job is created, within the startWindow after the doNotRunUntil time, and the schedule is complete as soon as that Job finishes. The minimum value is 1 minute. If you specify a lower value, the Batch service rejects the schedule with an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    - required_slots -- The number of scheduling slots that the Task requires to run. The default is 1. A Task can only be scheduled to run on a compute node if the node has enough free scheduling slots available. For multi-instance Tasks, this property is not supported and must not be specified.
    - start_window -- If a Job is not created within the startWindow interval, then the 'opportunity' is lost; no Job will be created until the next recurrence of the schedule. If the schedule is recurring, and the startWindow is longer than the recurrence interval, then this is equivalent to an infinite startWindow, because the Job that is 'due' in one recurrenceInterval is not carried forward into the next recurrence interval. The default is infinite. The minimum value is 1 minute. If you specify a lower value, the Batch service rejects the schedule with an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    - uses_task_dependencies -- Whether Tasks in the Job can define dependencies on each other. The default is false. True if flag present.
    '''
    return _call_az("az batch job-schedule reset", locals())


def disable(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - job_schedule_id -- The ID of the Job Schedule to disable.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch job-schedule disable", locals())


def enable(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - job_schedule_id -- The ID of the Job Schedule to enable.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch job-schedule enable", locals())


def stop(job_schedule_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - job_schedule_id -- The ID of the Job Schedule to terminates.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch job-schedule stop", locals())


def list(account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, select=None):
    '''
    

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand -- An OData $expand clause.
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-job-schedules.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch job-schedule list", locals())




'''
billing transaction
'''
from ... pyaz_utils import _call_az

def list(account_name, invoice_name):
    '''
    List the transactions for an invoice. Transactions include purchases, refunds and Azure usage charges.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - invoice_name -- The ID that uniquely identifies an invoice.
    '''
    return _call_az("az billing transaction list", locals())




from .... pyaz_utils import _call_az

def list(gateway_name, resource_group):
    '''
    List frontend IP addresses.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway frontend-ip list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a frontend IP address.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the frontend IP configuration.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway frontend-ip show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a frontend IP address.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the frontend IP configuration.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway frontend-ip delete", locals())


def create(gateway_name, name, resource_group, no_wait=None, private_ip_address=None, public_ip_address=None, subnet=None, vnet_name=None):
    '''
    Create a frontend IP address.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the frontend IP configuration.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - private_ip_address -- Static private IP address to use.
    - public_ip_address -- The name or ID of the public IP address.
    - subnet -- The name or ID of the subnet.
    - vnet_name -- The name of the virtual network corresponding to the subnet.
    '''
    return _call_az("az network application-gateway frontend-ip create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, no_wait=None, private_ip_address=None, public_ip_address=None, remove=None, set=None, subnet=None, vnet_name=None):
    '''
    Update a frontend IP address.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the frontend IP configuration.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - private_ip_address -- Static private IP address to use.
    - public_ip_address -- The name or ID of the public IP address.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - subnet -- The name or ID of the subnet.
    - vnet_name -- The name of the virtual network corresponding to the subnet.
    '''
    return _call_az("az network application-gateway frontend-ip update", locals())




'''
Manage the virtual router. This feature supports both VirtualHub and VirtualRouter. Considering VirtualRouter is deprecated, we recommend to create VirtualRouter with --hosted-subnet instead
'''
from ... pyaz_utils import _call_az
from . import peering


def create(name, resource_group, hosted_gateway=None, hosted_subnet=None, location=None, tags=None):
    '''
    Create a virtual router.

    Required Parameters:
    - name -- The name of the Virtual Router.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - hosted_gateway -- Name or ID of the virtual network gateway with ExpressRouter on which VirtualRouter is hosted.
    - hosted_subnet -- The ID of a subnet where VirtualRouter would be deployed
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network vrouter create", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a virtual router.

    Required Parameters:
    - name -- The name of the Virtual Router.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network vrouter update", locals())


def delete(name, resource_group):
    '''
    Delete a virtual router under a resource group.

    Required Parameters:
    - name -- The name of the Virtual Router.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vrouter delete", locals())


def show(name, resource_group):
    '''
    Show a virtual router.

    Required Parameters:
    - name -- The name of the Virtual Router.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vrouter show", locals())


def list(resource_group=None):
    '''
    List all virtual routers under a subscription or a resource group.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vrouter list", locals())




from .... pyaz_utils import _call_az

def show(namespace_name, resource_group):
    '''
    Get the private link resources that need to be created for a eventhubs namespace.

    Required Parameters:
    - namespace_name -- Name of the Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs namespace private-link-resource show", locals())




'''
Link or unlink a prexisting functionapp with a static webapp. Also known as "Bring your own Functions."
'''
from ... pyaz_utils import _call_az

def link(function_resource_id, name, resource_group, force=None):
    '''
    Link an Azure Function to a static webapp. Also known as "Bring your own Functions." Only one Azure Functions app is available to a single static web app. Static webapp SKU must be "Standard"

    Required Parameters:
    - function_resource_id -- Resource ID of the functionapp to link. Can be retrieved with 'az functionapp --query id'
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force -- Force the function link even if the function is already linked to a static webapp. May be needed if the function was previously linked to a static webapp.
    '''
    return _call_az("az staticwebapp functions link", locals())


def unlink(name, resource_group):
    '''
    Unlink an Azure Function from a static webapp

    Required Parameters:
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp functions unlink", locals())


def show(name, resource_group):
    '''
    Show details on the Azure Function linked to a static webapp

    Required Parameters:
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp functions show", locals())




from .... pyaz_utils import _call_az

def list(name, resource_group, slot=None):
    '''
    Get a web app's Azure storage account configurations. (Linux Web Apps and Windows Containers Web Apps Only)

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config storage-account list", locals())


def add(access_key, account_name, custom_id, name, resource_group, share_name, storage_type, mount_path=None, slot=None, slot_setting=None):
    '''
    Add an Azure storage account configuration to a web app. (Linux Web Apps and Windows Containers Web Apps Only)

    Required Parameters:
    - access_key -- storage account access key
    - account_name -- storage account name
    - custom_id -- name of the share configured within the web app
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - share_name -- name of the file share as given in the storage account
    - storage_type -- storage type

    Optional Parameters:
    - mount_path -- the path which the web app uses to read-write data ex: /share1 or /share2
    - slot -- the name of the slot. Default to the productions slot if not specified
    - slot_setting -- slot setting
    '''
    return _call_az("az webapp config storage-account add", locals())


def update(custom_id, name, resource_group, access_key=None, account_name=None, mount_path=None, share_name=None, slot=None, slot_setting=None, storage_type=None):
    '''
    Update an existing Azure storage account configuration on a web app. (Linux Web Apps and Windows Containers Web Apps Only)

    Required Parameters:
    - custom_id -- name of the share configured within the web app
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - access_key -- storage account access key
    - account_name -- storage account name
    - mount_path -- the path which the web app uses to read-write data ex: /share1 or /share2
    - share_name -- name of the file share as given in the storage account
    - slot -- the name of the slot. Default to the productions slot if not specified
    - slot_setting -- slot setting
    - storage_type -- storage type
    '''
    return _call_az("az webapp config storage-account update", locals())


def delete(custom_id, name, resource_group, slot=None):
    '''
    Delete a web app's Azure storage account configuration. (Linux Web Apps and Windows Containers Web Apps Only)

    Required Parameters:
    - custom_id -- name of the share configured within the web app
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config storage-account delete", locals())




'''
Manage SQL managed instance databases.
'''
from ... pyaz_utils import _call_az
from . import log_replay, ltr_backup, ltr_policy, short_term_retention_policy


def list_deleted(managed_instance, resource_group):
    '''
    List restorable deleted managed databases.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql midb list-deleted", locals())


def create(managed_instance, name, resource_group, collation=None, no_wait=None):
    '''
    Create a managed database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - collation -- The collation of the Azure SQL Managed Database collation to use, e.g.: SQL_Latin1_General_CP1_CI_AS or Latin1_General_100_CS_AS_SC
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql midb create", locals())


def restore(dest_name, managed_instance, name, resource_group, time, deleted_time=None, dest_mi=None, dest_resource_group=None, no_wait=None):
    '''
    Restore a managed database.

    Required Parameters:
    - dest_name -- Name of the managed database that will be created as the restore destination.
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - time -- The point in time of the source database that will be restored to create the new database. Must be greater than or equal to the source database's earliestRestoreDate value. Time should be in following format: "YYYY-MM-DDTHH:MM:SS".

    Optional Parameters:
    - deleted_time -- If specified, restore from a deleted database instead of from an existing database. Must match the deleted time of a deleted database on the source Managed Instance.
    - dest_mi -- Name of the managed instance to restore managed database to. This can be same managed instance, or another managed instance on same subscription. When not specified it defaults to source managed instance.
    - dest_resource_group -- Name of the resource group of the managed instance to restore managed database to. When not specified it defaults to source resource group.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql midb restore", locals())


def show(managed_instance, name, resource_group):
    '''
    Get the details for a managed database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql midb show", locals())


def list(managed_instance, resource_group):
    '''
    List managed databases on a managed instance.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql midb list", locals())


def delete(managed_instance, name, resource_group, no_wait=None, yes=None):
    '''
    Delete a managed database.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - name -- The name of the Azure SQL Managed Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql midb delete", locals())




'''
Manage and build image builder templates.
'''
from ... pyaz_utils import _call_az
from . import customizer, output


def create(name, resource_group, build_timeout=None, checksum=None, identity=None, image_source=None, image_template=None, location=None, managed_image_destinations=None, no_wait=None, os_disk_size=None, scripts=None, shared_image_destinations=None, subnet=None, tags=None, vm_size=None, vnet=None):
    '''
    Create an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - build_timeout -- The Maximum duration to wait while building the image template, in minutes. Default is 60.
    - checksum -- The SHA256 checksum of the Red Hat ISO image
    - identity -- List of user assigned identities (name or ID, space delimited) of the image template.
    - image_source -- The base image to customize. Must be a valid platform image URN, platform image alias, Red Hat ISO image URI, managed image name/ID, or shared image version ID.
    - image_template -- Local path or URL to an image template file. When using --image-template, all other parameters are ignored except -g and -n. Reference: https://docs.microsoft.com/azure/virtual-machines/linux/image-builder-json
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - managed_image_destinations -- Managed image output distributor information. Space-separated list of key-value pairs. E.g "image_1=westus2 image_2=westus". Each key is the name or resource ID of the managed image to be created. Each value is the location of the image.
    - no_wait -- Do not wait for the long-running operation to finish.
    - os_disk_size -- Size of the OS disk in GB. Omit or specify 0 to use Azure's default OS disk size
    - scripts -- Space-separated list of shell or powershell scripts to customize the image with. Each script must be a publicly accessible URL. Infers type of script from file extension ('.sh' or'.ps1') or from source type. More more customizer options and flexibility, see: 'az image template customizer add'
    - shared_image_destinations -- Shared image gallery (sig) output distributor information. Space-separated list of key-value pairs. E.g "my_gallery_1/image_def_1=eastus,westus  my_gallery_2/image_def_2=uksouth,canadaeast,francesouth." Each key is the sig image definition ID or sig gallery name and sig image definition delimited by a "/". Each value is a comma-delimited list of replica locations.
    - subnet -- Name or ID of subnet to deploy the build virtual machine
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vm_size -- Size of the virtual machine used to build, customize and capture images. Omit or specify empty string to use the default (Standard_D1_v2)
    - vnet -- Name of VNET to deploy the build virtual machine. You should only specify it when subnet is a name
    '''
    return _call_az("az image builder create", locals())


def list(resource_group=None):
    '''
    List image builder templates.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder list", locals())


def show(name, resource_group):
    '''
    Show an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder show", locals())


def delete(name, resource_group):
    '''
    Delete image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az image builder update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the template is met.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az image builder wait", locals())


def run(name, resource_group, no_wait=None):
    '''
    Build an image builder template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az image builder run", locals())


def show_runs(name, resource_group, output_name=None):
    '''
    Show an image builder template's run outputs.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - output_name -- Name of the image builder run output.
    '''
    return _call_az("az image builder show-runs", locals())


def cancel(name, resource_group):
    '''
    Cancel the long running image build based on the image template.

    Required Parameters:
    - name -- The name of the image template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image builder cancel", locals())




from .... pyaz_utils import _call_az

def create(hub_name, name, event_hub_name=None, resource_group=None):
    '''
    Create an event hub consumer group.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- Event hub consumer group name.

    Optional Parameters:
    - event_hub_name -- Event hub endpoint name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub consumer-group create", locals())


def list(hub_name, event_hub_name=None, resource_group=None):
    '''
    List event hub consumer groups.

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - event_hub_name -- Event hub endpoint name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub consumer-group list", locals())


def show(hub_name, name, event_hub_name=None, resource_group=None):
    '''
    Get the details for an event hub consumer group.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- Event hub consumer group name.

    Optional Parameters:
    - event_hub_name -- Event hub endpoint name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub consumer-group show", locals())


def delete(hub_name, name, event_hub_name=None, resource_group=None):
    '''
    Delete an event hub consumer group.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - name -- Event hub consumer group name.

    Optional Parameters:
    - event_hub_name -- Event hub endpoint name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub consumer-group delete", locals())




from .... pyaz_utils import _call_az

def upload(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, container_url=None, end_time=None, json_file=None, resource_id=None, start_time=None):
    '''
    

    Required Parameters:
    - node_id -- The ID of the Compute Node from which you want to upload the Azure Batch service log files.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - container_url -- Required. If a user assigned managed identity is not being used, the URL must include a Shared Access Signature (SAS) granting write permissions to the container. The SAS duration must allow enough time for the upload to finish. The start time for SAS is optional and recommended to not be specified.
    - end_time -- Any log file containing a log message in the time range will be uploaded. This means that the operation might retrieve more logs than have been requested since the entire log file is always uploaded, but the operation should not retrieve fewer logs than have been requested. If omitted, the default is to upload all logs available after the startTime. Expected format is an ISO-8601 timestamp.
    - json_file -- A file containing the upload batch service logs configuration specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Upload Batch Service Logs Configuration Arguments' are ignored.
    - resource_id -- The ARM resource id of the user assigned identity.
    - start_time -- Required. Any log file containing a log message in the time range will be uploaded. This means that the operation might retrieve more logs than have been requested since the entire log file is always uploaded, but the operation should not retrieve fewer logs than have been requested. Expected format is an ISO-8601 timestamp.
    '''
    return _call_az("az batch node service-logs upload", locals())




'''
Manage Synapse workspaces.
'''
from ... pyaz_utils import _call_az
from . import firewall_rule, key, managed_identity


def show(name, resource_group):
    '''
    Get a Synapse workspace.

    Required Parameters:
    - name -- The workspace name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az synapse workspace show", locals())


def list(resource_group=None):
    '''
    List all Synapse workspaces.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az synapse workspace list", locals())


def create(file_system, name, resource_group, sql_admin_login_password, sql_admin_login_user, storage_account, account_name=None, allowed_tenant_ids=None, collaboration_branch=None, enable_managed_vnet=None, host_name=None, key_identifier=None, key_name=None, location=None, no_wait=None, prevent_exfiltration=None, project_name=None, repository_name=None, repository_type=None, root_folder=None, tags=None, tenant_id=None):
    '''
    Create a Synapse workspace.

    Required Parameters:
    - file_system -- The file system of the data lake storage account.
    - name -- The workspace name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sql_admin_login_password -- The sql administrator login password.
    - sql_admin_login_user -- The sql administrator login user name.
    - storage_account -- The data lake storage account name or resource id.

    Optional Parameters:
    - account_name -- GitHub account name used for the repository or Azure devops organization name
    - allowed_tenant_ids -- The approved Azure AD tenants which outbound data traffic allowed to. The Azure AD tenant of the current user will be included by default. Use ('' in PowerShell) to disable all allowed tenant ids.
    - collaboration_branch -- The branch name where you will collaborate with others and from which you will publish.
    - enable_managed_vnet -- The flag indicates whether enable managed virtual network.
    - host_name -- If using github Enterprise Server, provide sever URL like https://github.mydomain.com.Do not use this option with GitHub Enterprise Cloud.
    - key_identifier -- The customer-managed key used to encrypt all data at rest in the workspace. Key identifier should be in the format of: https://{keyvaultname}.vault.azure.net/keys/{keyname}.
    - key_name -- The workspace customer-managed key display name. All existing keys can be found using "az synapse workspace key list" cmdlet.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - prevent_exfiltration -- The flag indicates whether enable data exfiltration.
    - project_name -- The project name to which you are connecting.
    - repository_name -- The name of the repository to which you are connecting.
    - repository_type -- The repository configuration type.
    - root_folder -- The name of the folder to the location of your Azure synapse JSON resources are imported. Default is /
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tenant_id -- The tenant id used to connect Azure devops
    '''
    return _call_az("az synapse workspace create", locals())


def update(name, resource_group, account_name=None, allowed_tenant_ids=None, collaboration_branch=None, host_name=None, key_name=None, no_wait=None, project_name=None, repository_name=None, repository_type=None, root_folder=None, sql_admin_login_password=None, tags=None, tenant_id=None):
    '''
    Update a Synapse workspace.

    Required Parameters:
    - name -- The workspace name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - account_name -- GitHub account name used for the repository or Azure devops organization name
    - allowed_tenant_ids -- The approved Azure AD tenants which outbound data traffic allowed to. The Azure AD tenant of the current user will be included by default. Use ('' in PowerShell) to disable all allowed tenant ids.
    - collaboration_branch -- The branch name where you will collaborate with others and from which you will publish.
    - host_name -- If using github Enterprise Server, provide sever URL like https://github.mydomain.com.Do not use this option with GitHub Enterprise Cloud.
    - key_name -- The workspace customer-managed key display name. All existing keys can be found using "az synapse workspace key list" cmdlet.
    - no_wait -- Do not wait for the long-running operation to finish.
    - project_name -- The project name to which you are connecting.
    - repository_name -- The name of the repository to which you are connecting.
    - repository_type -- The repository configuration type.
    - root_folder -- The name of the folder to the location of your Azure synapse JSON resources are imported. Default is /
    - sql_admin_login_password -- The sql administrator login password.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tenant_id -- The tenant id used to connect Azure devops
    '''
    return _call_az("az synapse workspace update", locals())


def check_name(name):
    '''
    Check if a Synapse workspace name is available or not.

    Required Parameters:
    - name -- The name you wanted to check.
    '''
    return _call_az("az synapse workspace check-name", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a Synapse workspace.

    Required Parameters:
    - name -- The workspace name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse workspace delete", locals())


def activate(key_identifier, name, resource_group, workspace_name, no_wait=None):
    '''
    Activates a workspace and change it's state from pending to success state when the workspace is first being provisioned and double encryption is enabled.

    Required Parameters:
    - key_identifier -- The Key Vault Url of the workspace encryption key. should be in the format of: https://{keyvaultname}.vault.azure.net/keys/{keyname}.
    - name -- The workspace customer-managed key display name. All existing keys can be found using /"az synapse workspace key list/" cmdlet.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse workspace activate", locals())


def wait(resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the workspace is met.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse workspace wait", locals())




from .... pyaz_utils import _call_az
from . import keys


def list(alias, namespace_name, resource_group):
    '''
    List of Authorizationrule by EventHubs Namespace

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias authorization-rule list", locals())


def show(alias, name, namespace_name, resource_group):
    '''
    Show properties of EventHubs Geo-Disaster Recovery Configuration Alias and Namespace Authorizationrule

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - name -- Name of Namespace AuthorizationRule
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias authorization-rule show", locals())




'''
Manage services running on an Azure Service Fabric cluster. Only support ARM deployed services.
'''
from ... pyaz_utils import _call_az

def list(application_name, cluster_name, resource_group):
    '''
    List services of a given application.

    Required Parameters:
    - application_name -- The name of the application resource.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf service list", locals())


def delete(application_name, cluster_name, name, resource_group):
    '''
    Delete a service.

    Required Parameters:
    - application_name -- The name of the application resource.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the name of the service. The application name must be a prefix of the service name, for example: appName~serviceName
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf service delete", locals())


def show(application_name, cluster_name, name, resource_group):
    '''
    Get a service.

    Required Parameters:
    - application_name -- The name of the application resource.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the name of the service. The application name must be a prefix of the service name, for example: appName~serviceName
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf service show", locals())


def create(application, cluster_name, name, resource_group, service_type, state, default_move_cost=None, instance_count=None, min_replica_set_size=None, partition_scheme=None, target_replica_set_size=None):
    '''
    Create a new service on an Azure Service Fabric cluster.

    Required Parameters:
    - application -- Specify the name of the service. The application name must be a prefix of the service name, for example: appName~serviceName
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the name of the service. The application name must be a prefix of the service name, for example: appName~serviceName
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - service_type -- Specify the service type name of the application, it should exist in the application manifest.
    - state -- Specify if the service is stateless or stateful.

    Optional Parameters:
    - default_move_cost -- Specify the default cost for a move. Higher costs make it less likely that the Cluster Resource Manager will move the replica when trying to balance the cluster.
    - instance_count -- Specify the instance count for the stateless service. If -1 is used, it means it will run on all the nodes.
    - min_replica_set_size -- Specify the min replica set size for the stateful service.
    - partition_scheme -- Specify what partition scheme to use. Singleton partitions are typically used when the service does not require any additional routing. UniformInt64 means that each partition owns a range of int64 keys. Named is usually for services with data that can be bucketed, within a bounded set. Some common examples of data fields used as named partition keys would be regions, postal codes, customer groups, or other business boundaries.
    - target_replica_set_size -- Specify the target replica set size for the stateful service.
    '''
    return _call_az("az sf service create", locals())




'''
Manage the rollouts.
'''
from ... pyaz_utils import _call_az

def show(resource_group, rollout_name, retry_attempt=None):
    '''
    Gets the rollout.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rollout_name -- The name of the rollout

    Optional Parameters:
    - retry_attempt -- Rollout retry attempt ordinal to get the result of. If not specified, result of the latest attempt will be returned.
    '''
    return _call_az("az deploymentmanager rollout show", locals())


def list(resource_group):
    '''
    List all rollouts in a resource group

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az deploymentmanager rollout list", locals())


def stop(resource_group, rollout_name, yes=None):
    '''
    Stop the rollout.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rollout_name -- The name of the rollout

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az deploymentmanager rollout stop", locals())


def restart(resource_group, rollout_name, skip_succeeded=None, yes=None):
    '''
    Restarts the rollout.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rollout_name -- The name of the rollout

    Optional Parameters:
    - skip_succeeded -- Skips all the steps that have succeeded in the previous retries of this rollout.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az deploymentmanager rollout restart", locals())


def delete(resource_group, rollout_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rollout_name -- The name of the rollout
    '''
    return _call_az("az deploymentmanager rollout delete", locals())




from .... pyaz_utils import _call_az
from . import address


def create(lb_name, name, resource_group, backend_address=None, backend_addresses_config_file=None):
    '''
    Create an address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - backend_address -- None
    - backend_addresses_config_file -- None
    '''
    return _call_az("az network cross-region-lb address-pool create", locals())


def show(lb_name, name, resource_group):
    '''
    

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb address-pool show", locals())


def list(lb_name, resource_group):
    '''
    

    Required Parameters:
    - lb_name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb address-pool list", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete an address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network cross-region-lb address-pool delete", locals())

